@@ -43,7 +43,6 @@ class MammotionBaseDevice:
         self._raw_mower_data: RawMowerData = RawMowerData()
         self._notify_future: asyncio.Future[bytes] | None = None
         self._cloud_device = cloud_device
-        self.command_sent_time: float = time.time()
 
     async def datahash_response(self, hash_ack: NavGetHashListAck) -> None:
         """Handle datahash responses for root level hashs."""
@@ -51,8 +50,8 @@ class MammotionBaseDevice:
 
         missing_frames = self.mower.map.missing_root_hash_frame(hash_ack)
         if len(missing_frames) == 0:
-            if len(self.mower.map.missing_hashlist(0)) > 0:
-                data_hash = self.mower.map.missing_hashlist(hash_ack.sub_cmd).pop()
+            if len(self.mower.map.missing_hashlist(hash_ack.sub_cmd)) > 0:
+                data_hash = self.mower.map.missing_hashlist(hash_ack.sub_cmd).pop(0)
                 await self.queue_command("synchronize_hash_data", hash_num=data_hash)
             return
 
@@ -70,7 +69,7 @@ class MammotionBaseDevice:
             # get next in hash ack list
 
             data_hash = (
-                self.mower.map.missing_hashlist(common_data.sub_cmd).pop()
+                self.mower.map.missing_hashlist(common_data.sub_cmd).pop(0)
                 if len(self.mower.map.missing_hashlist(common_data.sub_cmd)) > 0
                 else None
             )
@@ -210,7 +209,7 @@ class MammotionBaseDevice:
         await self.queue_command("get_device_product_model")
         await self.queue_command("get_report_cfg")
         """RTK and dock location."""
-        await self.queue_command("allpowerfull_rw", rw_id=5, context=1, rw=1)
+        await self.queue_command("read_write_device", rw_id=5, context=1, rw=1)
         await self.async_read_settings()
 
     async def start_map_sync(self) -> None:
@@ -261,13 +260,13 @@ class MammotionBaseDevice:
     async def async_read_settings(self) -> None:
         """Read settings from device."""
         # no cutting in rain nav_sys_param_cmd (id 3 context 1/0)
-        await self.queue_command("allpowerfull_rw", rw_id=3, context=1, rw=0)
+        await self.queue_command("read_write_device", rw_id=3, context=1, rw=0)
         # ??
-        await self.queue_command("allpowerfull_rw", rw_id=4, context=1, rw=0)
+        await self.queue_command("read_write_device", rw_id=4, context=1, rw=0)
         # turning mode nav_sys_param_cmd (id 6, context 1/0)
-        await self.queue_command("allpowerfull_rw", rw_id=6, context=1, rw=0)
+        await self.queue_command("read_write_device", rw_id=6, context=1, rw=0)
         # traversal mode
-        await self.queue_command("allpowerfull_rw", rw_id=7, context=1, rw=0)
+        await self.queue_command("read_write_device", rw_id=7, context=1, rw=0)
 
         await self.queue_command("read_and_set_sidelight", is_sidelight=True, operate=1)
 
@@ -275,8 +274,8 @@ class MammotionBaseDevice:
 
     async def async_get_errors(self) -> None:
         """Error codes."""
-        await self.queue_command("allpowerfull_rw", rw_id=5, rw=1, context=2)
-        await self.queue_command("allpowerfull_rw", rw_id=5, rw=1, context=3)
+        await self.queue_command("read_write_device", rw_id=5, rw=1, context=2)
+        await self.queue_command("read_write_device", rw_id=5, rw=1, context=3)
 
     async def command(self, key: str, **kwargs):
         """Send a command to the device."""
